@@ -13,7 +13,7 @@
 
 #include <math.h>
 
-#include <Plasma/Svg>
+#include <KSvg/Svg>
 
 #include <QPainter>
 #include <QPaintEvent>
@@ -21,10 +21,11 @@
 using namespace Knights;
 
 Clock::Clock(QWidget* parent) : QWidget(parent),
-	m_theme(new Plasma::Svg(this)),
+	m_theme(new KSvg::Svg(this)),
 	m_repaintCache(RepaintNone),
 	m_verticalTranslation(0.) {
 
+    m_theme->imageSet()->setBasePath(QStringLiteral("plasma/desktoptheme"));
 	m_theme->setImagePath(QStringLiteral("widgets/clock") );
 	m_theme->setContainsMultipleImages(true);
 }
