@@ -15,7 +15,7 @@
 #include <QWidget>
 #include <QTime>
 
-namespace Plasma {
+namespace KSvg {
 class Svg;
 }
 
@@ -48,7 +48,7 @@ private:
 	void paintInterface(QPainter *p, const QRect &rect);
 
 	QTime time;
-	Plasma::Svg *m_theme;
+	KSvg::Svg *m_theme;
 	enum RepaintCache {
 		RepaintNone,
 		RepaintAll,
