@@ -3,16 +3,13 @@
     Project              : Knights
     Description          : Dialogs for setting custom difficulty
     --------------------------------------------------------------------
-    Copyright            : (C) 2016 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2016 Alexander Semke (alexander.semke@web.de)
 
  ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *                                                                         *
  *  This program is distributed in the hope that it will be useful,        *
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
@@ -63,3 +60,5 @@ int DifficultyDialog::memorySize() const {
 int DifficultyDialog::searchDepth() const {
 	return ui->sbSearchDepth->value();
 }
+
+#include "moc_difficultydialog.cpp"
